@@ -14,6 +14,8 @@ from .levels import (
     CombinedData,
     BinnedData,
     DayAveragedData,
+    CombinedBinnedData,
     read_step,
     ModelData,
+    RawData,
 )
